# ART VAULT

Art vault is a web app used for art vendors to keep track of their sales. 
It's a simple coded project for the final semester project that showcases what I learnt throughout semester. 

The process for using it goes like this: You run the app.py file, you get a link which you Ctrl+Click and you get
redirected to the web app. There you find a clear presentation of what to write in. Then you fill in the required information 
and add it. After that, the database get's updated to include new data you just added.

## Brief Description
- Add new sold artworks
- View sales history
- Integration of a database using SQLite
- Responsive UI using HMTL and CSS

## Features

- Object-Oriented Programming: Implemented through classes in models.py
- Inheritance: Classes inherit from the base class
- Polymorphism
- Modules and Packages: Code is organized into separate modules (app.py for the web app, models.py for classes, database.py for data operations)
- SQLite with Python: uses sqlite3 module to create a database
- Virtual Environment and Requirements
- JSON with Python


## How to use

1. **Installation**

 ```
 Run in Terminal: pip install flask
```

2. **Running**

 ```
 Run 'app.py file
 ```

 5. **Open in browser**  
   - Go to [http://127.0.0.1:5000](http://127.0.0.1:5000)
